define(
//begin v1.x content
({
	fontSize: "Størrelse",
	fontName: "Skrift",
	formatBlock: "Format",

	serif: "serif",
	"sans-serif": "sans-serif",
	monospace: "monospace",
	cursive: "kursiv",
	fantasy: "fantasi",

	noFormat: "Ingen",
	p: "Avsnitt",
	h1: "Overskrift",
	h2: "Undertittel",
	h3: "Under-undertittel",
	pre: "Forhåndsformatert",

	1: "xx-liten",
	2: "x-liten",
	3: "liten",
	4: "middels",
	5: "stor",
	6: "x-stor",
	7: "xx-stor"
})
//end v1.x content
);
